@@ -7,12 +7,13 @@ from .errors import ClientNotRegisteredError
 
 
 @contextlib.contextmanager
-def reset_client(new_client: Optional[RegisteredClient] = None) -> Iterator[None]:
+def reset_client(
+    new_client: Optional[RegisteredClient] = None,
+) -> Iterator[None]:
     """Context manager to unregister the current client
 
     Once the context manager exits, the registered client is set back to it's original state
     """
-    # pylint: disable=protected-access
     client = _client._registered_client
     if client is None:
         raise ClientNotRegisteredError()
